starlane_space::space::parse

Function lex_nested_block

pub fn lex_nested_block<I>(
    kind: NestedBlockKind,
) -> impl FnMut(I) -> Res<I, LexBlock<I>>
rough block simply makes sure that the opening and closing symbols match it accounts for multiple embedded blocks of the same kind but NOT of differing kinds