pub enum Status {
Unknown,
Pending,
Init,
Panic,
Fatal,
Ready,
Paused,
Resuming,
Done,
}Variants
Unknown
initial status or when status cannot be determined
Pending
initial status
Init
undergoing custom initialization…This particle can send requests but not receive requests.
Panic
something is wrong… all requests are blocked and responses are cancelled.
Fatal
unrecoverable panic
Ready
ready to take requests
Paused
can not receive requests (probably because it is waiting for some other particle to make updates)…
Resuming
like Initializing but triggered after a pause is lifted, the particle may be doing something before it is ready to accept requests again.
Done
this particle had a life span and has now completed succesfully it can no longer receive requests.