pub struct EchoCore {
pub to: Surface,
pub intended: Recipients,
pub core: ReflectedCore,
pub reflection_of: WaveId,
}Fields
to: Surfacethis is meant to be the intended request recipient, which may not be the point responding to this message in the case it was intercepted and filtered at some point
intended: Recipientscore: ReflectedCorereflection_of: WaveIdImplementations