pub struct PongCore {
pub to: Surface,
pub intended: Recipients,
pub core: ReflectedCore,
pub reflection_of: WaveId,
}Fields
to: Surfacethis is meant to be the intended request recipient, which may not be the point responding to this message in the case it was intercepted and filtered at some point
intended: Recipientscore: ReflectedCorereflection_of: WaveIdImplementations
Sourceimpl PongCore
impl PongCore
pub fn is_ok(&self) -> bool
pub fn core<E>(result: Result<WaveVariantDef<PongCore>, E>) -> ReflectedCore
pub fn as_result<E: From<&'static str>, P: TryFrom<Substance>>( self, ) -> Result<P, E>
pub fn ok_or_anyhow(&self) -> Result<(), Arc<Error>>
pub fn ok_or(&self) -> Result<(), SpaceErr>
Sourceimpl PongCore
impl PongCore
pub fn new( core: ReflectedCore, to: Surface, intended: Recipients, reflection_of: WaveId, ) -> Self