pub fn lex_nested_block<I>(
kind: NestedBlockKind,
) -> impl FnMut(I) -> Res<I, LexBlock<I>>Expand description
rough block simply makes sure that the opening and closing symbols match it accounts for multiple embedded blocks of the same kind but NOT of differing kinds