pub type SpaceTree<I: Span> = GenericErrorTree<I, &'static str, ErrCtx, ParseErrs>;Aliased Type
enum SpaceTree<I: Span> {
Base {
location: I,
kind: BaseErrorKind<&'static str, ParseErrs>,
},
Stack {
base: Box<GenericErrorTree<I, &'static str, ErrCtx, ParseErrs>>,
contexts: Vec<(I, StackContext<ErrCtx>)>,
},
Alt(Vec<GenericErrorTree<I, &'static str, ErrCtx, ParseErrs>>),
}Variants
Base
A specific error event at a specific location. Often this will indicate that something like a tag or character was expected at that location.
Fields

location: IThe location of this error in the input

kind: BaseErrorKind<&'static str, ParseErrs>The specific error that occurred
Stack
A stack indicates a chain of error contexts was provided. The stack
should be read “backwards”; that is, errors earlier in the Vec
occurred “sooner” (deeper in the call stack).
Fields

contexts: Vec<(I, StackContext<ErrCtx>)>The stack of contexts attached to that error
Alt(Vec<GenericErrorTree<I, &'static str, ErrCtx, ParseErrs>>)
A series of parsers were tried at the same location (for instance, via
the alt combinator) and all of them failed. All
of the errors in this set are “siblings”.