pub type PointCtx = PointDef<RouteSeg, PointSegCtx>;Expand description
A Point with potential contextual information for example one with a working dir:
.:mechtrons:mechtron the single . works the same as in unix shell and refers to the working
location. You can also reference parent hierarchies just as you would expect: ..:another-app:something
In order to create an absolute Point from a PointCtx one must call the PointCtx::to_resolved(&env) method with a proper Env (environment) reference which should have a contextual point set:
use std::str::FromStr;
use starlane_space::loc::Point;
use starlane_space::loc::PointCtx;
let point_var = PointCtx::from_str("..:another-app:something")?;
let point: Point = point_ctx.to_resolve(&env)?;Aliased Type
struct PointCtx {
pub route: RouteSeg,
pub segments: Vec<PointSegCtx>,
}Fields
route: RouteSegsegments: Vec<PointSegCtx>