starlane_space::space::wave::exchange

Enum SetStrategy

pub enum SetStrategy<T> {
    None,
    Fill(T),
    Override(T),
}

Variants



None

The ProtoTransmitter will NOT set a value



Fill(T)

The ProtoTransmitter will set the DirectedProto value unless the value was already explicitly set



Override(T)

The ProtoTransmitter will override the DirectedProto value even if it has already been explicitly set

Implementations

Source

impl<T> SetStrategy<T>

pub fn unwrap(self) -> Result<T, SpaceErr>

Source

impl SetStrategy<Surface>

pub fn with_topic(self, topic: Topic) -> Result<Self, SpaceErr>